#!/usr/bin/python

"""
tricorder.py
version 0.6

An attempt at a Star Trek "TR580 TRICORDER VII" simulator, written in PyGame
(a cross-platform set of Python modules designed for writing video games).

This software is "as is", and has no warranty of any kind.  The author assumes no
responsibility for the consequences of any use of this software.

This is, of course, for entertainment purposes only.  

The orientation of the simulation is specifically designed for use on the
Nokia internet tablet devices (N770, N8xx), though the simulation should
run just fine on any PC with the appropriate Python libraries.

More information regarding these fictional devices is available at:

http://memory-alpha.org/en/wiki/Starfleet_tricorder
http://en.wikipedia.org/wiki/Tricorder

For more information about this simulator, see the accompanying 'README' file.

Star Trek, and all associated marks, images and characteristics are registered 
trademarks of Paramount Pictures, all rights reserved.

More information about Python and PyGame is available at:

http://www.python.org/
http://www.pygame.org/news.html

Copyright (C) 2008 Darren Enns <dmenns1@gmail.com>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
USA.
"""

try:
	import sys
	import time
	import os
	import math
	import pygame
	import random
	import datetime
	from pygame.locals import *
	import urllib2
	import xml.dom.minidom
	import urllib
	import socket
except ImportError, err:
	print "couldn't load module. %s" % (err)
	sys.exit(2)

try:
	import hildon
	hildon_flag = 1
except ImportError:
	hildon_flag = -1
	print "not on maemo platform"

try:
	import gpsbt
	gps_flag = 1
except ImportError:
	gps_flag = -1
	print "maemo gps not present"

timeout = 10

socket.setdefaulttimeout(timeout)
screen_width  = 130
screen_height = 225
bar_inc = 9999
video_radius = 9999
video_width = 130
video_depth = 225
video_xpos = 162
video_ypos = 65
ball_xpos = random.randrange(video_xpos+10,video_xpos+video_width)
ball_ypos = random.randrange(video_ypos,video_ypos+video_depth)
line_ypos = 9999
black = (0,0,0)
white = (255,255,255)
greenh = (0,255,0)
greenl = (0,128,0)
redh = (255,0,0)
redl = (128,0,0)
yellow = (255,255,0)

def download_location(screen, font, text_xpos, text_ypos, latitude_value, longitude_value):
	text = font.render('GPS SEARCHING...PLEASE WAIT', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	pygame.display.flip()

	text_xpos = video_xpos+8

	if gps_flag != -1:
    		gps_position = get_gps_location()
	else:
		#gps_position = [-999,-999]
		gps_position = [latitude_value, longitude_value]

	if gps_position[0] == -999:
		gps_position = [latitude_value, longitude_value]

	#text = font.render('                                                                                      ', True, (255, 255, 255), (0,0,0))
	#text = pygame.transform.rotate( text, 90 )
	#text_area = text.get_rect(center=(text_xpos,text_ypos))
       	#screen.blit(text, text_area)

	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("GEOLOGY", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	current_date = datetime.datetime.now()
	now = datetime.datetime(current_date.year, current_date.month, current_date.day, current_date.hour, current_date.minute)
	text = font.render('DATE/TIME: '+str(now), True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render('Latitude: '+str(gps_position[0]), True, (255, 255, 255), (0,0,0))

	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render(' Longitude: '+str(gps_position[1]), True, (255, 255, 255), (0,0,0))

	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	pygame.display.flip()

def draw_bio_scan_wide(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos):
	global video_radius, ball_xpos, ball_ypos

	if video_radius > 60:
		video_radius = 4 
		pygame.draw.rect (screen, black, video_area)

		text_xpos = video_xpos+8
		text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
		text = pygame.transform.rotate( text, 90 )
		#text_xpos = text_xpos+15
		text_area = text.get_rect(center=(text_xpos,text_ypos))
       		screen.blit(text, text_area)

		text = font.render("BIOLOGY", True, (0,0,0), (255,255,0))
		text = pygame.transform.rotate( text, 90 )
		#text_xpos = text_xpos+15
		text_area = text.get_rect(center=(text_xpos,text_ypos))
       		screen.blit(text, text_area)

	pygame.draw.circle(screen, white, (video_xpos+(video_width/2)+10,video_ypos+(video_depth/2)), video_radius, 1)
	pygame.draw.circle(screen,black,(ball_xpos,ball_ypos),3,0)

	ball_move = 10
	ball_xpos = ball_xpos+random.randrange(-ball_move,ball_move)
    	ball_ypos = ball_ypos+random.randrange(-ball_move,ball_move)

	if ball_xpos < video_xpos+20:
		ball_xpos=ball_xpos+ball_move
	if ball_xpos > video_xpos+video_width:
		ball_xpos=ball_xpos-ball_move
	if ball_ypos < video_ypos:
		ball_ypos=ball_ypos+ball_move
	if ball_ypos > video_ypos+video_depth:
		ball_ypos=ball_ypos-ball_move

	pygame.draw.circle(screen,greenh,(ball_xpos,ball_ypos),3,0)

	video_radius = video_radius+10

def draw_bars(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos):
	global bar_inc

	if bar_inc > 11:
		bar_inc = 1
		pygame.draw.rect (screen, black, video_area)
		text_xpos = video_xpos+8
		text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
		text = pygame.transform.rotate( text, 90 )
		#text_xpos = text_xpos+15
		text_area = text.get_rect(center=(text_xpos,text_ypos))
       		screen.blit(text, text_area)

		text = font.render("FULL SCAN", True, (0,0,0), (255,255,0))
		text = pygame.transform.rotate( text, 90 )
		#text_xpos = text_xpos+15
		text_area = text.get_rect(center=(text_xpos,text_ypos))
       		screen.blit(text, text_area)
        barw = random.randrange(bar_inc*7,bar_inc*10)
	bard = 19

       	barx = video_xpos+video_width-barw
       	bary = video_ypos+video_depth-(bar_inc*20-1)

       	bar = pygame.Rect(barx,bary,barw,bard)
       	pygame.draw.rect (screen, redh, bar)
       	pygame.display.flip()
	bar_inc = bar_inc+1

def get_gps_location():
    	context = gpsbt.start()

    	if context == None:
        	print 'Problem while connecting!'
        	gps_position = (-999,-999)
        	return gps_position
        	#return 

    	# ensure that GPS device is ready to connect and to receive commands
    	time.sleep(2)
    	gpsdevice = gpsbt.gps()

    	gpsdevice.get_fix()

    	print "Waiting for location..."
    	while gpsdevice.get_position()[0] == 0.0:
        	sys.stdout.write('.')
        	time.sleep(2)

    	sys.stdout.write('\n')

    	gps_position = gpsdevice.get_position()
    	# ends Bluetooth connection
    	gpsbt.stop(context)

    	return gps_position

def download_globe_weath(screen, font, video_area, text_xpos, text_ypos, latitude_value, longitude_value):
	if longitude_value < 0:
		east_west_direction = "West"
		longitude_unsigned_value = -longitude_value
	else:
		east_west_direction = "East"
		longitude_unsigned_value = longitude_value

	if latitude_value < 0:
		north_south_direction = "South"
		latitude_unsigned_value = -latitude_value
	else:
		north_south_direction = "North"
		latitude_unsigned_value = latitude_value

	text = font.render('RETRIEVING IMAGE...PLEASE WAIT', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	pygame.display.flip()

	text_xpos = video_xpos+8

	#url = 'http://www.ssec.wisc.edu/data/comp/latest_cmoll.gif'
	url = 'http://www.fourmilab.ch/cgi-bin/Earth?img=wx-cmap.bmp&imgsize=320&dynimg=y&opt=-l&lat='
	url = url+str(latitude_unsigned_value)+"&ns="+north_south_direction+"&lon="+str(longitude_unsigned_value)+"&ew="+east_west_direction+"&alt=35785&tle=&date=0&utc=&jd="

	try:
		file = urllib.urlopen(url)
		weather_pic = file.read()
		run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
		data_dir = os.path.join(run_dir, 'data')
		file_name = os.path.join(data_dir, 'globe_weath.gif')	
		temp_file = open(file_name,"wb")
		temp_file.write(weather_pic)
		temp_file.close()
	except Exception:
		print "web connection timeout"

	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'globe_weath.gif')	
	weather_pic = pygame.image.load(file_name).convert()
	weather_pic = pygame.transform.rotate(weather_pic,90)
	#weather_pic = pygame.transform.scale(weather_pic,(screen_width, screen_height))
	weather_pic = pygame.transform.scale(weather_pic,(screen_width-20, screen_width-20))

	pygame.draw.rect (screen, black, video_area)
	screen.blit(weather_pic, (video_xpos+20,video_ypos+(video_depth/4))) 
	pygame.display.flip() 

	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("METEOROLOGY", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

def download_map_weath(screen, font, text_xpos, text_ypos):
	text = font.render('RETRIEVING IMAGE...PLEASE WAIT', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	pygame.display.flip()

	text_xpos = video_xpos+8

	#url = 'http://www.ssec.wisc.edu/data/comp/latest_cmoll.gif'
	url = 'http://www.fourmilab.ch/cgi-bin/Earth?img=wx-cmap.bmp&imgsize=320&dynimg=y&opt=-p&lat=&lon=&alt=&tle=&date=0&utc=&jd='

	try:
		file = urllib.urlopen(url)
		weather_pic = file.read()
		run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
		data_dir = os.path.join(run_dir, 'data')
		file_name = os.path.join(data_dir, 'map_weath.gif')	
		temp_file = open(file_name,"wb")
		temp_file.write(weather_pic)
		temp_file.close()
	except Exception:
	#except IOError:
		print "web connection timeout"

	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'map_weath.gif')	
	weather_pic = pygame.image.load(file_name).convert()
	weather_pic = pygame.transform.rotate(weather_pic,90)
	weather_pic = pygame.transform.scale(weather_pic,(screen_width, screen_height))

	screen.blit(weather_pic, (video_xpos,video_ypos)) 
	pygame.display.flip() 

	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("METEOROLOGY", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

def download_globe_topo(screen, font, video_area, text_xpos, text_ypos, latitude_value, longitude_value):
	global video_xpos, video_ypos
	if longitude_value < 0:
		east_west_direction = "West"
		longitude_unsigned_value = -longitude_value
	else:
		east_west_direction = "East"
		longitude_unsigned_value = longitude_value

	if latitude_value < 0:
		north_south_direction = "South"
		latitude_unsigned_value = -latitude_value
	else:
		north_south_direction = "North"
		latitude_unsigned_value = latitude_value

	text = font.render('RETRIEVING IMAGE...PLEASE WAIT', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	pygame.display.flip()

	text_xpos = video_xpos+8

	url = 'http://www.fourmilab.ch/cgi-bin/Earth?img=NOAAtopo.evif&imgsize=130&dynimg=y&opt=-l&lat='
	url = url+str(latitude_unsigned_value)+"&ns="+north_south_direction+"&lon="+str(longitude_unsigned_value)+"&ew="+east_west_direction+"&alt=35785&tle=&date=0&utc=&jd="

	try:
		file = urllib.urlopen(url)
		weather_pic2 = file.read()
		run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
		data_dir = os.path.join(run_dir, 'data')
		file_name = os.path.join(data_dir, 'globe_topo.gif')	
		temp_file = open(file_name,"wb")
		temp_file.write(weather_pic2)
		temp_file.close()
	except Exception:
		print "web connection timeout"

	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'globe_topo.gif')	
	weather_pic = pygame.image.load(file_name).convert()
	weather_pic = pygame.transform.rotate(weather_pic,90)
	weather_pic = pygame.transform.scale(weather_pic,(screen_width-20, screen_width-20))

	pygame.draw.rect (screen, black, video_area)
	screen.blit(weather_pic, (video_xpos+20,video_ypos+(video_depth/4))) 
	pygame.display.flip() 

	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("GEOLOGY", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

def download_user_info(screen, font, text_xpos, text_ypos, user_name):
	global video_xpos, video_ypos

	#text = font.render('RETRIEVING IMAGE...PLEASE WAIT', True, (255, 255, 255), (0,0,0))
	#text = pygame.transform.rotate( text, 90 )
	#text_xpos = text_xpos+20
	#text_area = text.get_rect(center=(text_xpos,text_ypos))
       	#screen.blit(text, text_area)

	#pygame.display.flip()

	text_xpos = video_xpos+8

	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'user.jpg')	
	user_pic = pygame.image.load(file_name).convert()
	user_pic = pygame.transform.rotate(user_pic,90)
	user_pic = pygame.transform.scale(user_pic,(screen_width-20, screen_width-20))

	screen.blit(user_pic, (video_xpos+20,video_ypos+(video_depth/4))) 
	pygame.display.flip() 

	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	#text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("USER IDENTIFIED: "+user_name, True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

def download_map_topo(screen, font, text_xpos, text_ypos):
	global video_xpos, video_ypos
	text = font.render('RETRIEVING IMAGE...PLEASE WAIT', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	pygame.display.flip()

	text_xpos = video_xpos+8

	url = 'http://www.fourmilab.ch/cgi-bin/Earth?img=NOAAtopo.evif&imgsize=320&dynimg=y&opt=-p&lat=&lon=&alt=&tle=&date=0&utc=&jd='

	try:
		file = urllib.urlopen(url)
		weather_pic2 = file.read()
		run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
		data_dir = os.path.join(run_dir, 'data')
		file_name = os.path.join(data_dir, 'map_topo.gif')	
		temp_file = open(file_name,"wb")
		temp_file.write(weather_pic2)
		temp_file.close()
	except Exception:
		print "web connection timeout"

	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'map_topo.gif')	
	weather_pic = pygame.image.load(file_name).convert()
	weather_pic = pygame.transform.rotate(weather_pic,90)
	weather_pic = pygame.transform.scale(weather_pic,(screen_width, screen_height))

	screen.blit(weather_pic, (video_xpos,video_ypos)) 
	pygame.display.flip() 

	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	#text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("GEOLOGY", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

def download_weather(screen, font, text_xpos, text_ypos, zip_code, unit='c'):
	url = 'http://weather.yahoo.com/forecastrss?p=%s&u=%s'
	url = url % (zip_code, unit)
	dom = xml.dom.minidom.parse(urllib2.urlopen(url))

	xml_value = dom.getElementsByTagName('yweather:location')[0]
	city_name = xml_value.getAttribute('city')
	country_name = xml_value.getAttribute('country')

	xml_value = dom.getElementsByTagName('yweather:astronomy')[0]
	sunrise_time = xml_value.getAttribute('sunrise')
	sunset_time = xml_value.getAttribute('sunset')

	xml_value = dom.getElementsByTagName('yweather:atmosphere')[0]
	humidity_value = xml_value.getAttribute('humidity')
	visibility_value = xml_value.getAttribute('visibility')
	pressure_value = xml_value.getAttribute('pressure')
	rising_flag = xml_value.getAttribute('rising')

	xml_value = dom.getElementsByTagName('yweather:wind')[0]
	wind_chill = xml_value.getAttribute('chill')
	wind_direction = xml_value.getAttribute('direction')
	wind_speed = xml_value.getAttribute('speed')

	xml_value = dom.getElementsByTagName('yweather:units')[0]
	temperature_unit = xml_value.getAttribute('temperature')
	distance_unit = xml_value.getAttribute('distance')
	pressure_unit = xml_value.getAttribute('pressure')
	speed_unit = xml_value.getAttribute('speed')

	xml_value = dom.getElementsByTagName('yweather:condition')[0]
	temperature = xml_value.getAttribute('temp')

	xml_value = dom.getElementsByTagName('yweather:condition')[0]

	latitude_value = dom.getElementsByTagName('geo:lat')[0].firstChild.data
	longitude_value = dom.getElementsByTagName('geo:long')[0].firstChild.data
	weather_date = dom.getElementsByTagName('pubDate')[0].firstChild.data

	if rising_flag == "0":
		rising_value = "Steady"

	if rising_flag == "1":
		rising_value = "Rising"

	if rising_flag == "2":
		rising_value = "Falling"

	degree_symbol = unichr(176)

	text = font.render("LOCATION: "+city_name+" "+country_name+" "+latitude_value+degree_symbol+" "+longitude_value+degree_symbol, True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	#text_xpos = text_xpos+15
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("DATE/TIME: "+weather_date, True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("TEMPERATURE: "+temperature+" "+temperature_unit, True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("WIND: "+wind_speed+" "+speed_unit+" "+wind_direction+degree_symbol, True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("HUMIDITY: "+humidity_value+" %", True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("PRESSURE: "+pressure_value+" "+pressure_unit+" "+rising_value, True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("VISIBILITY: "+visibility_value+" "+distance_unit, True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	#text = font.render("SUNRISE: "+sunrise_time, True, (255, 255, 255), (0,0,0))
	#text = pygame.transform.rotate( text, 90 )
	#text_xpos = text_xpos+15
	#text_area = text.get_rect(center=(text_xpos,text_ypos))
       	#screen.blit(text, text_area)

	#text = font.render("SUNSET: "+sunset_time, True, (255, 255, 255), (0,0,0))
	#text = pygame.transform.rotate( text, 90 )
	#text_xpos = text_xpos+15
	#text_area = text.get_rect(center=(text_xpos,text_ypos))
       	#screen.blit(text, text_area)

def download_bio_text(screen, font, text_xpos, text_ypos):
	degree_symbol = unichr(176)

	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("BIOLOGY", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	neural_activity_index = random.randrange (80,120)	
	heart_rate = random.randrange(60,90)
	pulse_oximetry = random.randrange(96,100)
	systolic = random.randrange(110,140)
	diastolic = random.randrange(70,90)
	respiration = random.randrange(15,20)
	temperature = random.randrange(361,372)

	text = font.render("NEURAL ACTIVITY INDEX: "+str(neural_activity_index), True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+20
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("HEART RATE: "+str(heart_rate)+' bpm', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("PULSE OXIMETRY: "+str(pulse_oximetry)+'%', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("BLOOD PRESSURE: "+str(systolic)+'/'+str(diastolic)+' mmHg', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("RESPIRATION: "+str(respiration)+' bpm', True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

	text = font.render("TEMPERATURE: "+str(temperature/10.0)+degree_symbol, True, (255, 255, 255), (0,0,0))
	text = pygame.transform.rotate( text, 90 )
	text_xpos = text_xpos+15
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

def draw_bio_scan_narrow(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos, lifeform_pic, lifeform_name, font_big):
	global line_ypos

	if line_ypos > video_ypos+video_depth:
		pygame.draw.rect (screen, black, video_area)
		screen.blit(lifeform_pic, (video_xpos+20,video_ypos)) 
		pygame.display.flip() 

		text_xpos = video_xpos+8
		text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
		text = pygame.transform.rotate( text, 90 )
		text_area = text.get_rect(center=(text_xpos,text_ypos))
       		screen.blit(text, text_area)

		text = font.render("BIOLOGY", True, (0,0,0), (255,255,0))
		text = pygame.transform.rotate( text, 90 )
		text_area = text.get_rect(center=(text_xpos,text_ypos))
       		screen.blit(text, text_area)

		if line_ypos != 9999:
			text = font_big.render(lifeform_name, True, (255, 255, 255), (0,0,0))
			text = pygame.transform.rotate( text, 90 )
			text_xpos = text_xpos+70
			text_area = text.get_rect(center=(text_xpos,text_ypos))
       			screen.blit(text, text_area)

			print "lifeform_name",lifeform_name

		pygame.display.flip() 
		pygame.time.wait(1000)
		line_ypos = video_ypos+1

	screen.blit(lifeform_pic, (video_xpos+20,video_ypos)) 
	pygame.draw.line(screen,greenh,(video_xpos+20,line_ypos),(video_xpos+video_width-1,line_ypos),3)
	pygame.display.flip() 
	
	line_ypos = line_ypos+20

def load_png(name):
	fullname = os.path.join('./',name)
	try:
		image = pygame.image.load(fullname)
		if image.get_alpha() is None:
			image = image.convert()
		else:
			image = image.convert_alpha()
			print "alpha image!"
	except pygame.error, message:
		print "Can't load image:" , fullname
		raise SystemExit, message
	return image, image.get_rect()

def main():
	pygame.init()
	clock = pygame.time.Clock()

	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'tricorder.dat')	
	file = open(file_name, "r")

	user_name = file.readline()
	user_name = user_name.rstrip('\n')

	weather_code = file.readline()
	weather_code = weather_code.rstrip('\n')

	latitude_value = file.readline()
	latitude_value = latitude_value.rstrip('\n')
	latitude_value = eval(latitude_value)

	longitude_value = file.readline()
	longitude_value = longitude_value.rstrip('\n')
	longitude_value = eval(longitude_value)

	lifeform1_name = file.readline()
	lifeform1_name = lifeform1_name.rstrip('\n')

	lifeform2_name = file.readline()
	lifeform2_name = lifeform2_name.rstrip('\n')

	lifeform3_name = file.readline()
	lifeform3_name = lifeform3_name.rstrip('\n')

	lifeform4_name = file.readline()
	lifeform4_name = lifeform4_name.rstrip('\n')

	file.close()

	if hildon_flag != -1:
        	screen = pygame.display.set_mode((800, 480),FULLSCREEN,16)
	else:
        	screen = pygame.display.set_mode((800, 480))

	screen_rect=screen.get_rect()
	pygame.display.set_caption('Tricorder')
	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'tricorder.png')	
	background = pygame.image.load(file_name).convert_alpha()
	
        screen.blit(background,(0, 0))
        pygame.display.flip()

	alpha_width = 19
	alpha_depth = 46

	alphax = 138
	alphay = 359

	beta_xpos = 179
	beta_ypos = 359

	delta_xpos = 221
	delta_ypos = 359

	gamma_xpos = 262
	gamma_ypos = 359
	
	alpha_light = pygame.Rect(alphax,alphay,alpha_width,alpha_depth)
	pygame.draw.rect (screen, greenl, alpha_light)
        pygame.display.flip()

	beta_light = pygame.Rect(beta_xpos,beta_ypos,alpha_width,alpha_depth)
	pygame.draw.rect (screen, greenl, beta_light)
        pygame.display.flip()

	delta_light = pygame.Rect(delta_xpos,delta_ypos,alpha_width,alpha_depth)
	pygame.draw.rect (screen, greenl, delta_light)
        pygame.display.flip()

	gamma_light = pygame.Rect(gamma_xpos,gamma_ypos,alpha_width,alpha_depth)
	pygame.draw.rect (screen, greenl, gamma_light)
        pygame.display.flip()

	id_width = 42
	id_depth = 62

	id_xpos = 738
	id_ypos = 356

	id_button = pygame.Rect(id_xpos,id_ypos,id_width,id_depth)

	id_light_width = 23
	id_light_depth = 21

	id_light_xpos = 748
	id_light_ypos = 384

	id_light = pygame.Rect(id_light_xpos,id_light_ypos,id_light_width,id_light_depth)
	pygame.draw.rect (screen, redl, id_light)

	power_width = 59
	power_depth = 62

	power_xpos = 46
	power_ypos = 350

	power_button = pygame.Rect(power_xpos,power_ypos,power_width,power_depth)

	standby_width = 10
	standby_depth = 19

	standby_xpos = 88
	standby_ypos = 373

	standby_light = pygame.Rect(standby_xpos,standby_ypos,standby_width,standby_depth)
	pygame.draw.rect (screen, redl, standby_light)

	device_input_width = 14
	device_input_depth = 22

	device_input_xpos = 349
	device_input_ypos = 65

	device_input2_xpos = 375
	device_input2_ypos = 65

	device_input3_xpos = 404
	device_input3_ypos = 65

	device_input1_light = pygame.Rect(device_input_xpos,device_input_ypos,device_input_width,device_input_depth)
	pygame.draw.rect (screen, redl, device_input1_light)
        pygame.display.flip()

	device_input2_light = pygame.Rect(device_input2_xpos,device_input2_ypos,device_input_width,device_input_depth)
	pygame.draw.rect (screen, greenl, device_input2_light)
        pygame.display.flip()

	device_input3_light = pygame.Rect(device_input3_xpos,device_input3_ypos,device_input_width,device_input_depth)
	pygame.draw.rect (screen, greenl, device_input3_light)
        pygame.display.flip()

	geo_width = 61
	geo_depth = 61

	geo_xpos = 358
	geo_ypos = 248

	met_xpos = 358
	met_ypos = 176

	bio_xpos = 358
	bio_ypos = 104

	geo_button = pygame.Rect(geo_xpos,geo_ypos,geo_width,geo_depth)
	met_button = pygame.Rect(met_xpos,met_ypos,geo_width,geo_depth)
	bio_button = pygame.Rect(bio_xpos,bio_ypos,geo_width,geo_depth)

	geo_light_width = 13
	geo_light_depth = 25

	geo_light_xpos = 396
	geo_light_ypos = 267

	met_light_xpos = 396
	met_light_ypos = 196

	bio_light_xpos = 396
	bio_light_ypos = 123

	bio1_xpos = bio_xpos
	bio1_ypos = bio_ypos+(geo_depth/2)

	bio2_xpos = bio_xpos
	bio2_ypos = bio_ypos

	bio3_xpos = bio_xpos+(geo_width/2)
	bio3_ypos = bio_ypos+(geo_depth/2)

	bio4_xpos = bio_xpos+(geo_width/2)
	bio4_ypos = bio_ypos

	geo_light_button = pygame.Rect(geo_light_xpos,geo_light_ypos,geo_light_width,geo_light_depth)
	pygame.draw.rect (screen, greenl, geo_light_button)
	pygame.display.flip()

	met_light_button = pygame.Rect(met_light_xpos,met_light_ypos,geo_light_width,geo_light_depth)
	pygame.draw.rect (screen, greenl, met_light_button)
	pygame.display.flip()

	bio_light_button = pygame.Rect(bio_light_xpos,bio_light_ypos,geo_light_width,geo_light_depth)
	pygame.draw.rect (screen, greenl, bio_light_button)
	pygame.display.flip()

	bio1_button = pygame.Rect(bio1_xpos,bio1_ypos,geo_width/2,geo_depth/2)
	bio2_button = pygame.Rect(bio2_xpos,bio2_ypos,geo_width/2,geo_depth/2)
	bio3_button = pygame.Rect(bio3_xpos,bio3_ypos,geo_width/2,geo_depth/2)
	bio4_button = pygame.Rect(bio4_xpos,bio4_ypos,geo_width/2,geo_depth/2)

	emergency_width = 36
	emergency_depth = 41

	emergency_xpos = 502
	emergency_ypos = 100

	emergency_button = pygame.Rect(emergency_xpos,emergency_ypos,emergency_width,emergency_depth)
	pygame.draw.rect (screen, redl, emergency_button)
	pygame.display.flip()

	emergency_on_flag = 0

	video_area = pygame.Rect(video_xpos,video_ypos,video_width,video_depth)
	pygame.draw.rect (screen, black, video_area)

	video_on_flag = 1

        #font = pygame.font.Font(None, 15)
	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'lcars.ttf')	
        font = pygame.font.Font(file_name, 15)
      	font_big = pygame.font.Font(file_name, 30)

	text_xpos = video_xpos+8
	text_ypos = video_ypos+(video_depth/2)
 
	text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
	text = pygame.transform.rotate( text, 90 )
	text_area = text.get_rect(center=(text_xpos,text_ypos))
       	screen.blit(text, text_area)

    	# Read sounds
	
	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'beep.wav')	
    	beep_sound = pygame.mixer.Sound(file_name)
	file_name = os.path.join(data_dir, 'emergency.wav')	
    	emergency_sound = pygame.mixer.Sound(file_name)
	file_name = os.path.join(data_dir, 'toggle_on.wav')	
	toggle_on_sound = pygame.mixer.Sound(file_name)
	file_name = os.path.join(data_dir, 'toggle_off.wav')	
	toggle_off_sound = pygame.mixer.Sound(file_name)
	file_name = os.path.join(data_dir, 'function.wav')	
	function_sound = pygame.mixer.Sound(file_name)
	file_name = os.path.join(data_dir, 'standby.wav')	
	standby_sound = pygame.mixer.Sound(file_name)
	file_name = os.path.join(data_dir, 'user.wav')	
	user_sound = pygame.mixer.Sound(file_name)
	file_name = os.path.join(data_dir, 'scan.wav')	
    	scan_sound = pygame.mixer.Sound(file_name)
        scan_sound.play(-1,0)
	scan_volume = 1.0
		
	source_external_width = 43
	source_external_depth = 45

	source_external_xpos = 55
	source_external_ypos = 58

	soure_internal_xpos = 55
	source_internal_ypos = 124
 
	source_external_button = pygame.Rect(source_external_xpos,source_external_ypos,source_external_width,source_external_depth)
	source_internal_button = pygame.Rect(soure_internal_xpos,source_internal_ypos,source_external_width,source_external_depth)

	source_external_on_flag = 1
	source_internal_on_flag = 1

	primary_flag = -1
	map_mode_flag = 1

	function_width = 57
	function_depth = 61

	function_xpos = 48
	function_ypos = 251

	function_button = pygame.Rect(function_xpos, function_ypos, function_width, function_depth)

	scan_mode = "all"
	
	run_dir = os.path.dirname(os.path.abspath(sys.argv[0]))
	data_dir = os.path.join(run_dir, 'data')
	file_name = os.path.join(data_dir, 'lifeform.jpg')	
	lifeform_pic = pygame.image.load(file_name).convert()
	lifeform_pic = pygame.transform.scale(lifeform_pic,(screen_width-20, screen_height))

	pygame.draw.rect (screen, greenh, geo_light_button)
	pygame.draw.rect (screen, greenh, met_light_button)
	pygame.draw.rect (screen, greenh, bio_light_button)
       	pygame.display.flip()

	clock = pygame.time.Clock()
	total_ticks = 0
	pause = 0

    	# Game loop
    	exit = False
    	while not exit:
		if video_on_flag == 1:
			if scan_mode == "bio":
				if map_mode_flag == -1:
					draw_bio_scan_narrow(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos, lifeform_pic, lifeform_name, font_big)
				else:
					draw_bio_scan_wide(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos)

			if scan_mode == "all":			
				draw_bars(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos)

		if scan_mode != "none":
			pygame.draw.rect (screen, greenl, alpha_light)
			pygame.draw.rect (screen, greenl, beta_light)
			pygame.draw.rect (screen, greenl, delta_light)
			pygame.draw.rect (screen, greenh, gamma_light)

			pygame.draw.rect (screen, redl, device_input1_light)
			pygame.draw.rect (screen, greenl, device_input2_light)
			pygame.draw.rect (screen, greenh, device_input3_light)

			pygame.display.flip()
			pygame.time.wait(100)

			if video_on_flag == 1:
				if scan_mode == "all":			
					draw_bars(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos)

			pygame.draw.rect (screen, greenl, alpha_light)
			pygame.draw.rect (screen, greenl, beta_light)
			pygame.draw.rect (screen, greenh, delta_light)
			pygame.draw.rect (screen, greenl, gamma_light)

			pygame.draw.rect (screen, redl, device_input1_light)
			pygame.draw.rect (screen, greenh, device_input2_light)
			pygame.draw.rect (screen, greenl, device_input3_light)

			pygame.display.flip()
			pygame.time.wait(100)

			if video_on_flag == 1:
				if scan_mode == "all":			
					draw_bars(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos)

			pygame.draw.rect (screen, greenl, alpha_light)
			pygame.draw.rect (screen, greenh, beta_light)
			pygame.draw.rect (screen, greenl, delta_light)
			pygame.draw.rect (screen, greenl, gamma_light)

			pygame.draw.rect (screen, redh, device_input1_light)
			pygame.draw.rect (screen, greenl, device_input2_light)
			pygame.draw.rect (screen, greenl, device_input3_light)

			pygame.display.flip()
			pygame.time.wait(100)

			if video_on_flag == 1:
				if scan_mode == "all":			
					draw_bars(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos)

			pygame.draw.rect (screen, greenh, alpha_light)
			pygame.draw.rect (screen, greenl, beta_light)
			pygame.draw.rect (screen, greenl, delta_light)
			pygame.draw.rect (screen, greenl, gamma_light)

			pygame.display.flip()
			pygame.time.wait(100)

        	# Handle events
        	for event in pygame.event.get():
            		if event.type == QUIT:
                		exit = True

            		elif event.type == KEYDOWN:
                		if event.key == K_ESCAPE:
                    			exit = True

            		elif event.type == MOUSEBUTTONDOWN:
				clock = pygame.time.Clock()
				total_ticks = 0
                		x,y = pygame.mouse.get_pos()
                		#if (imagerect.collidepoint(x,y)):

                		if (power_button.collidepoint(x,y)):
                    			exit = True

                		if (source_external_button.collidepoint(x,y)):
					if source_external_on_flag == 0:
                    				toggle_on_sound.play()
						source_external_on_flag = 1
						pygame.draw.rect (screen, black, video_area)
						text_xpos = video_xpos+8
						text = font.render("                                                                                                                  ", True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
       						screen.blit(text, text_area)

						text = font.render('EXTERNAL SENSOR ACTIVATED', True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)
						video_on_flag = 0
					else:
                    				toggle_off_sound.play()
						source_external_on_flag = 0
						pygame.draw.rect (screen, black, video_area)
						text_xpos = video_xpos+8
						text = font.render("                                                                                                                  ", True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
       						screen.blit(text, text_area)

						text = font.render('EXTERNAL SENSOR DE-ACTIVATED', True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)
						pygame.time.wait(1000)
						video_on_flag = 0

                		if (source_internal_button.collidepoint(x,y)):
					if source_internal_on_flag == 0:
                    				toggle_on_sound.play()
						source_internal_on_flag = 1
						pygame.draw.rect (screen, black, video_area)
						text_xpos = video_xpos+8
						text = font.render("                                                                                                                  ", True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
       						screen.blit(text, text_area)

						text = font.render('INTERNAL SENSOR ACTIVATED', True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)
						video_on_flag = 0
					else:
                    				toggle_off_sound.play()
						source_internal_on_flag = 0
						pygame.draw.rect (screen, black, video_area)
						text_xpos = video_xpos+8
						text = font.render("                                                                                                                  ", True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
       						screen.blit(text, text_area)

						text = font.render('INTERNAL SENSOR DE-ACTIVATED', True, (0,0,0), (0,255,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)
						pygame.time.wait(1000)
						video_on_flag = 0

                		if (emergency_button.collidepoint(x,y)):
					#if emergency_on_flag == 0:
						emergency_on_flag = 1
						pygame.draw.rect (screen, redh, emergency_button)
						pygame.draw.rect (screen, redh, video_area)

						text_xpos = video_xpos+40

						text = font.render(' EMERGENCY DATA DUMP ', True, (255, 255, 255), (0,0,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)

						text = font_big.render(' IN PROGRESS ', True, (255, 255, 255), (0,0,0))
						text = pygame.transform.rotate( text, 90 )
						text_xpos = text_xpos+30
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)

        					pygame.display.flip()

						video_on_flag = 0
						scan_sound.stop()
        					emergency_sound.play(-1,0)
						pygame.time.wait(5000)
					#else:
						emergency_on_flag = 0

						pygame.draw.rect (screen, redh, video_area)

						text_xpos = video_xpos+40

						text = font.render(' EMERGENCY DATA DUMP ', True, (255, 255, 255), (0,0,0))
						text = pygame.transform.rotate( text, 90 )
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)

						text = font_big.render(' COMPLETE ', True, (255, 255, 255), (0,0,0))
						text = pygame.transform.rotate( text, 90 )
						text_xpos = text_xpos+30
						text_area = text.get_rect(center=(text_xpos,text_ypos))
        					screen.blit(text, text_area)
        					pygame.display.flip()

						pygame.time.wait(1000)

						pygame.draw.rect (screen, redl, emergency_button)
						pygame.draw.rect (screen, black, video_area)
						pygame.draw.rect (screen, greenh, geo_light_button)
						pygame.draw.rect (screen, greenh, met_light_button)
						pygame.draw.rect (screen, greenh, bio_light_button)
       						pygame.display.flip()
						scan_mode = "all"
						video_on_flag = 1
        					pygame.display.flip()

						emergency_sound.stop()
        					scan_sound.play(-1,0)

                		if (geo_button.collidepoint(x,y)):
					scan_mode = "geo"

					if scan_mode == "geo":
						primary_flag = -primary_flag

                    			beep_sound.play()

					if primary_flag == -1 and source_internal_on_flag == 0:
						primary_flag = 1
					if primary_flag == 1 and source_external_on_flag == 0:
						primary_flag = -1

					pygame.draw.rect (screen, greenh, geo_light_button)
					pygame.draw.rect (screen, greenl, met_light_button)
					pygame.draw.rect (screen, greenl, bio_light_button)
					pygame.draw.rect (screen, black, video_area)
        				pygame.display.flip()

					text_xpos = video_xpos+8
					pygame.draw.rect (screen, black, video_area)

					text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
					text = pygame.transform.rotate( text, 90 )

					#text_xpos = text_xpos+15
					text_area = text.get_rect(center=(text_xpos,text_ypos))
       					screen.blit(text, text_area)

					text = font.render('GEOLOGY', True, (0,0,0), (255,255,0))
					text = pygame.transform.rotate( text, 90 )
					text_area = text.get_rect(center=(text_xpos,text_ypos))
        				screen.blit(text, text_area)

					if primary_flag == 1:
						video_on_flag = 0
						if map_mode_flag == -1:
							download_globe_topo(screen, font, video_area, text_xpos, text_ypos, latitude_value, longitude_value)
						else:
							download_map_topo(screen, font, text_xpos, text_ypos)
					else:
						video_on_flag = 0
						download_location(screen, font, text_xpos, text_ypos, latitude_value, longitude_value)

                		if (met_button.collidepoint(x,y)):
                    			beep_sound.play()

					if scan_mode == "met":
						primary_flag = -primary_flag

					scan_mode = "met"

					if primary_flag == -1 and source_internal_on_flag == 0:
						primary_flag = 1
					if primary_flag == 1 and source_external_on_flag == 0:
						primary_flag = -1

					pygame.draw.rect (screen, greenl, geo_light_button)
					pygame.draw.rect (screen, greenh, met_light_button)
					pygame.draw.rect (screen, greenl, bio_light_button)
        				pygame.display.flip()

					text_xpos = video_xpos+8
					pygame.draw.rect (screen, black, video_area)

					text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
					text = pygame.transform.rotate( text, 90 )
					text_area = text.get_rect(center=(text_xpos,text_ypos))
       					screen.blit(text, text_area)

					text = font.render("METEOROLOGY", True, (0,0,0), (255,255,0))
					text = pygame.transform.rotate( text, 90 )
					text_area = text.get_rect(center=(text_xpos,text_ypos))
       					screen.blit(text, text_area)

					if primary_flag == -1:
						#weather = download_weather(screen,font,text_xpos,text_ypos,'CAXX0547')
						weather = download_weather(screen,font,text_xpos,text_ypos,weather_code)
					else:
						if map_mode_flag == -1:
							download_globe_weath(screen,font,video_area,text_xpos,text_ypos,latitude_value,longitude_value)
						else:
							download_map_weath(screen,font,text_xpos,text_ypos)

					video_on_flag = 0

                		if (bio1_button.collidepoint(x,y)):
                    			beep_sound.play()
					lifeform_name = lifeform1_name
					print "lifeform name",lifeform_name

                		if (bio2_button.collidepoint(x,y)):
                    			beep_sound.play()
					lifeform_name = lifeform2_name
					print "lifeform name",lifeform_name

                		if (bio3_button.collidepoint(x,y)):
                    			beep_sound.play()
					lifeform_name = lifeform3_name
					print "lifeform name",lifeform_name

                		if (bio4_button.collidepoint(x,y)):
                    			beep_sound.play()
					lifeform_name = lifeform4_name
					print "lifeform name",lifeform_name

                		if (bio_button.collidepoint(x,y)):
                    			beep_sound.play()

					if scan_mode == "bio":
						primary_flag = -primary_flag

					scan_mode = "bio"

					if primary_flag == -1 and source_internal_on_flag == 0:
						primary_flag = 1
					if primary_flag == 1 and source_external_on_flag == 0:
						primary_flag = -1

					pygame.draw.rect (screen, greenl, geo_light_button)
					pygame.draw.rect (screen, greenl, met_light_button)
					pygame.draw.rect (screen, greenh, bio_light_button)
        				pygame.display.flip()

					text_xpos = video_xpos+8
					pygame.draw.rect (screen, black, video_area)

					text = font.render("                                                                                                                  ", True, (0,0,0), (255,255,0))
					text = pygame.transform.rotate( text, 90 )
					#text_xpos = text_xpos+15
					text_area = text.get_rect(center=(text_xpos,text_ypos))
       					screen.blit(text, text_area)

					text = font.render("BIOLOGY", True, (0,0,0), (255,255,0))
					text = pygame.transform.rotate( text, 90 )
					text_area = text.get_rect(center=(text_xpos,text_ypos))
       					screen.blit(text, text_area)

					if primary_flag == -1:
						video_on_flag = 0
						download_bio_text(screen, font, text_xpos, text_ypos)
					else:
						video_on_flag = 1
						if map_mode_flag == -1:
							draw_bio_scan_narrow(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos, lifeform_pic, lifeform_name, font_big)
						else:
							draw_bio_scan_wide(screen, font, video_area, video_xpos, video_ypos, video_width, video_depth, text_xpos, text_ypos)

					#print "primary_flag=",primary_flag
					#print "video_on_flag=",video_on_flag
					#print "map_mode_flag=",map_mode_flag

                		if (function_button.collidepoint(x,y)):
					map_mode_flag = -map_mode_flag
                    			function_sound.play()
					pygame.draw.rect (screen, black, video_area)
					text_xpos = video_xpos+8
					text = font.render("                                                                                                                  ", True, (0,0,0), (0,255,0))
					text = pygame.transform.rotate( text, 90 )
					text_area = text.get_rect(center=(text_xpos,text_ypos))
       					screen.blit(text, text_area)

					text = font.render('SENSOR MODE TOGGLED', True, (0,0,0), (0,255,0))
					text = pygame.transform.rotate( text, 90 )
					text_area = text.get_rect(center=(text_xpos,text_ypos))
       					screen.blit(text, text_area)
					pygame.time.wait(1000)

				if (id_button.collidepoint(x,y)):
                    			user_sound.play()
					pygame.draw.rect (screen, redh, id_light)
					pygame.draw.rect (screen, black, video_area)

					video_on_flag = 0
					download_user_info(screen, font, text_xpos, text_ypos, user_name)
			
				if (video_area.collidepoint(x,y)):
                    			beep_sound.play()
					if scan_mode == "all":
						scan_volume = scan_volume - 0.2
						scan_sound.set_volume(scan_volume)
						if scan_volume < 0.0:
							scan_volume = 1.0
							scan_sound.set_volume(scan_volume)
					scan_mode = "all"
					video_on_flag = 1
					pygame.draw.rect (screen, black, video_area)
					pygame.draw.rect (screen, greenh, geo_light_button)
					pygame.draw.rect (screen, greenh, met_light_button)
					pygame.draw.rect (screen, greenh, bio_light_button)
       					pygame.display.flip()

        	pygame.display.update()

		ticks = clock.tick()
		total_ticks = total_ticks+ticks
		if total_ticks > 30000:
			if pause == 0:
				pause = 1
				#break
				scan_sound.stop()
                    		standby_sound.play()
				standby_light = pygame.Rect(standby_xpos,standby_ypos,standby_width,standby_depth)
				pygame.draw.rect (screen, redh, standby_light)
				pygame.draw.rect (screen, greenh, video_area)

				text_xpos = video_xpos+40

				text = font.render(' POWER STANDBY ', True, (255, 255, 255), (0,0,0))
				text = pygame.transform.rotate( text, 90 )
				text_area = text.get_rect(center=(text_xpos,text_ypos))
       				screen.blit(text, text_area)

				text = font_big.render(' ACTIVATED ', True, (255, 255, 255), (0,0,0))
				text = pygame.transform.rotate( text, 90 )
				text_xpos = text_xpos+30
				text_area = text.get_rect(center=(text_xpos,text_ypos))
       				screen.blit(text, text_area)

       				pygame.display.flip()

				scan_mode = "none"
				pygame.time.wait(1000)
		else:
			if pause == 1:
				pause = 0
				standby_light = pygame.Rect(standby_xpos,standby_ypos,standby_width,standby_depth)
				pygame.draw.rect (screen, redl, standby_light)
				pygame.draw.rect (screen, black, video_area)
				pygame.draw.rect (screen, greenh, geo_light_button)
				pygame.draw.rect (screen, greenh, met_light_button)
				pygame.draw.rect (screen, greenh, bio_light_button)
       				pygame.display.flip()
				scan_mode = "all"
				video_on_flag = 1
				scan_sound.play(-1,0)

    	# Exit Pygame
    	pygame.quit()

if __name__ == '__main__': main()
